@@ -2,35 +2,45 @@
 # Copyright (c) 2020-2021 Pinecone Systems Inc. All right reserved.
 #
 
-import json
 import time
-from typing import NamedTuple
+from typing import NamedTuple, Optional
 
+import pinecone
 from pinecone.config import Config
 from pinecone.core.client.api.index_operations_api import IndexOperationsApi
 from pinecone.core.client.api_client import ApiClient
-from pinecone.core.client.configuration import Configuration
 from pinecone.core.client.model.create_request import CreateRequest
 from pinecone.core.client.model.patch_request import PatchRequest
+from pinecone.core.client.model.create_collection_request import CreateCollectionRequest
 from pinecone.core.utils import get_user_agent
 
 __all__ = [
-    "create_index", "delete_index", "describe_index", "list_indexes", "scale_index", "IndexDescription"
+    "create_index", "delete_index", "describe_index", "list_indexes", "scale_index", "IndexDescription",
+    "create_collection", "describe_collection", "list_collections", "delete_collection", "configure_index",
+    "CollectionDescription"
 ]
 
 
 class IndexDescription(NamedTuple):
     name: str
-    index_type: str
     metric: str
     replicas: int
     dimension: int
     shards: int
     pods: int
     pod_type: str
-    index_config: None
     status: None
     metadata_config: None
+    source_collection: None
+
+
+class CollectionDescription(object):
+    def __init__(self, keys, values):
+        for k, v in zip(keys, values):
+            self.__dict__[k] = v
+
+    def __str__(self):
+        return str(self.__dict__)
 
 
 def _get_api_instance():
@@ -66,7 +76,8 @@ def create_index(
         pods: int = 1,
         pod_type: str = 'p1',
         index_config: dict = None,
-        metadata_config: dict = None
+        metadata_config: dict = None,
+        source_collection: str = '',
 ):
     """Creates a Pinecone index.
 
@@ -97,6 +108,8 @@ def create_index(
     :param index_config: Advanced configuration options for the index
     :param metadata_config: Configuration related to the metadata index
     :type metadata_config: dict, optional
+    :param source_collection: Collection name to create the index from
+    :type metadata_config: str, optional
     :type timeout: int, optional
     :param timeout: Timeout for wait until index gets ready. If None, wait indefinitely; if >=0, time out after this many seconds; if -1, return immediately and do not wait. Default: None
     """
@@ -112,7 +125,8 @@ def create_index(
         pods=pods,
         pod_type=pod_type,
         index_config=index_config or {},
-        metadata_config=metadata_config
+        metadata_config=metadata_config,
+        source_collection=source_collection
     ))
 
     def is_ready():
@@ -183,10 +197,11 @@ def describe_index(name: str):
     db = response['database']
     ready = response['status']['ready']
     state = response['status']['state']
-    return IndexDescription(name=db['name'], index_type=db['index_type'], metric=db['metric'],
+    return IndexDescription(name=db['name'], metric=db['metric'],
                             replicas=db['replicas'], dimension=db['dimension'], shards=db['shards'],
-                            pods=db.get('pods', db['shards']*db['replicas']), pod_type=db.get('pod_type', 'p1'),
-                            index_config=db['index_config'], status={'ready': ready, 'state': state}, metadata_config=db.get('metadata_config'))
+                            pods=db.get('pods', db['shards'] * db['replicas']), pod_type=db.get('pod_type', 'p1'),
+                            status={'ready': ready, 'state': state}, metadata_config=db.get('metadata_config'),
+                            source_collection=db.get('source_collection', ''))
 
 
 def scale_index(name: str, replicas: int):
@@ -198,4 +213,58 @@ def scale_index(name: str, replicas: int):
     :type replicas: int
     """
     api_instance = _get_api_instance()
-    api_instance.scale_index(name, patch_request=PatchRequest(replicas=replicas))
+    api_instance.configure_index(name, patch_request=PatchRequest(replicas=replicas, pod_type=""))
+
+
+def create_collection(
+        name: str,
+        source: str
+):
+    """Create a collection
+    :param: name: Name of the collection
+    :param: source: Name of the source index
+    """
+    api_instance = _get_api_instance()
+    api_instance.create_collection(create_collection_request=CreateCollectionRequest(name=name, source=source))
+
+
+def list_collections():
+    """List all collections"""
+    api_instance = _get_api_instance()
+    response = api_instance.list_collections()
+    return response
+
+
+def delete_collection(name: str):
+    """Deletes a collection.
+    :param: name: The name of the collection
+    """
+    api_instance = _get_api_instance()
+    api_instance.delete_collection(name)
+
+
+def describe_collection(name: str):
+    """Describes a collection.
+    :param: The name of the collection
+    :return: Description of the collection
+    """
+    api_instance = _get_api_instance()
+    response = api_instance.describe_collection(name).to_dict()
+    response_object = CollectionDescription(response.keys(), response.values())
+    return response_object
+
+
+def configure_index(name: str, replicas: Optional[int] = None, pod_type: Optional[str] = ""):
+    """Changes current configuration of the index.
+       :param: name: the name of the Index
+       :param: replicas: the desired number of replicas, lowest value is 0.
+       :param: pod_type: the new pod_type for the index.
+       """
+    api_instance = _get_api_instance()
+    config_args = {}
+    if pod_type != "":
+        config_args.update(pod_type=pod_type)
+    if replicas:
+        config_args.update(replicas=replicas)
+    patch_request = PatchRequest(**config_args)
+    api_instance.configure_index(name, patch_request=patch_request)
